@@ -1,5 +1,4 @@
 from .exceptions import SNSobjectException
-from .parser import parse_content
 
 class SNSinteraction:
 
@@ -17,9 +16,14 @@ class SNSinteraction:
 
         if len(self.headers) > 0:
             interaction_string += '\r\n'
-            interaction_string += '\r\n'.join(header[0] + ": " + header[1] for header in self.headers)
+            interaction_string += '\r\n'.join([header[0] + ": " + str(header[1]) for header in self.headers.items()])
 
-        return interaction_string.decode('utf-8') + '\r\n\r\n' + self.content.to_bytes()
+        content_bytes = self.content.to_bytes()
+
+        if len(content_bytes) > 0:
+            return interaction_string.encode('utf-8') + b'\r\n\r\n' + content_bytes
+        else:
+            return interaction_string.encode('utf-8')
 
 class SNScontent:
 
@@ -28,11 +32,28 @@ class SNScontent:
         self.__encrypted_content = []
         self.__attachments = []
 
+        if isinstance(content, list):
+            for item in content:
+                self.set_content(item)
+        else:
+            self.set_content(content)
+
+
+    def set_content(self, content):
         if type(content) == str:
             # try to parse, since it's probably decrypted content
-            parsed_content = parse_content(content)
-            if isinstance(parsed_content, dict):
+            try:
+                content_parameters = content.splitlines()
+                parsed_content = {}
+
+                for content_parameter in content_parameters:
+                    param_type, param_value = content_parameter.split(": ")
+
+                    parsed_content[param_type] = param_value
+
                 self.__decrypted_content.append(parsed_content)
+            except:
+                raise SNSobjectException(content, "Content was passed as a str, but could not be parsed to a dict")
         elif isinstance(content, dict):
             # decrypted content
             self.__decrypted_content.append(content)
@@ -58,10 +79,12 @@ class SNScontent:
         return self.__attachments
 
     def to_bytes(self):
-        decrypted_bytes = b'\r\n'.join([(key + ': ' + value).encode('utf-8') for key, value in self.__decrypted_content.items()])
+        result_bytes = b'\r\n\r\n'.join([b'\r\n'.join([(key + ': ' + value).encode('utf-8') for key, value in item.items()]) for item in self.__decrypted_content]) 
 
-        encrypted_bytes = b'\r\n'.join(self.__encrypted_content)
+        if len(self.__encrypted_content) > 0:
+            result_bytes += b'\r\n\r\n' + b'\r\n'.join(self.__encrypted_content)
 
-        attachments_bytes = b'\r\n'.join(self.__attachments)
+        if len(self.__attachments) > 0:
+            result_bytes += b'\r\n\r\n' + b'\r\n'.join([b'Attachment: ' + attachment for attachment in self.__attachments])
 
-        return decrypted_bytes + b'\r\n\r\n' + encrypted_bytes + '\r\n\r\n' + attachments_bytes
\ No newline at end of file
+        return result_bytes
\ No newline at end of file
