@@ -68,22 +68,24 @@ class SNSserver(object):
             conn.settimeout(2)
             while True:
                 try:
+                    buffer_size = 4096
                     data = b''
-                    count = 0
 
                     while True:
-                        temp_data = conn.recv(5120)
-                        if (len(temp_data) < 1): break
-                        time.sleep(0.2)
-                        count = count + len(temp_data)
+                        temp_data = conn.recv(buffer_size)
                         data += temp_data
+                        if (len(temp_data) < buffer_size): break
+                        time.sleep(0.2)
+
+                    if len(data) == 0:
+                        break
 
                     interaction_blobs = data.split(b'\r\n\r\n')
 
                     interactions = []
                     for interaction_blob in interaction_blobs:
                         try:
-                            interaction = parse(interaction_blob)
+                            interactions.append(parse(interaction_blob))
                         except:
                             if len(interactions) > 0:
                                 interactions[-1].content.append(interaction_blob)
@@ -91,38 +93,54 @@ class SNSserver(object):
                                 raise SNSserverException()
 
                     print(addr, "Received interaction:")
-                    print(interaction_object)
+                    print(interactions)
 
-                    if (interaction_object.type, interaction_object.action) in SNSserver.components:
-                        response = SNSserver.components[interaction_object.type, interaction_object.action](interaction_object)
-                    elif (interaction_object.type, "*") in SNSserver.components:
-                        response = SNSserver.components[interaction_object.type, "*"](interaction_object)
-                    elif ("*", interaction_object.action) in SNSserver.components:
-                        response = SNSserver.components["*", interaction_object.action](interaction_object)
-                    elif ("*", "*") in SNSserver.components:
-                        response = SNSserver.components["*", "*"](interaction_object)
-                    else:
-                        print(addr, "Interaction component not found")
-                        response = SNSinteraction("STATUS", 404, {'From':interaction_object.headers['To'], 'To':interaction_object.headers['From']})
+                    responses = []
+
+                    for interaction_object in interactions:
+                        response = None
+                        if (interaction_object.type, interaction_object.action) in SNSserver.components:
+                            response = SNSserver.components[interaction_object.type, interaction_object.action](interaction_object)
+                        elif (interaction_object.type, "*") in SNSserver.components:
+                            response = SNSserver.components[interaction_object.type, "*"](interaction_object)
+                        elif ("*", interaction_object.action) in SNSserver.components:
+                            response = SNSserver.components["*", interaction_object.action](interaction_object)
+                        elif ("*", "*") in SNSserver.components:
+                            response = SNSserver.components["*", "*"](interaction_object)
+                        else:
+                            print(addr, "Interaction component not found")
+                            response = SNSinteraction("STATUS", 404, {'From':interaction_object.headers['To'], 'To':interaction_object.headers['From']})
+
+                        if response is None:
+                            continue
+                        elif isinstance(response, list):
+                            responses += response
+                        else:
+                            responses.append(response)
+
+                    if len(responses) == 0:
+                        raise SNSserverException()
 
                     print(addr, "Constructed response:")
-                    if isinstance(response, list):
-                        if len(response) == 0:
-                            response = SNSinteraction("STATUS", 401, {'From':interaction_object.headers['To'], 'To':interaction_object.headers['From']})
-                            print(response.type, response.action)
-                            print(response.headers)
-                            conn.sendall(response.to_bytes())
-                        else:
-                            print('\n'.join([item.type + ' ' + item.action + '\n' + item.headers for item in response]))
-                            conn.sendall(b'\r\n\r\n'.join([item.to_bytes() for item in response]))
-                    else:
+                    if len(responses) == 0:
+                        response = SNSinteraction("STATUS", 401, {'From':responses[0].headers['To'], 'To':responses[1].headers['From']})
                         print(response.type, response.action)
                         print(response.headers)
-                        conn.sendall(str(response).encode("utf-8"))
+                        conn.sendall(response.to_bytes())
+                    elif len(responses) == 1:
+                        response = responses[0]
+                        print(response.type, response.action)
+                        print(response.headers)
+                        conn.sendall(response.to_bytes())
+                    else:
+                        print('\n'.join([item.type + ' ' + item.action + '\n' + item.headers for item in responses]))
+                        conn.sendall(b'\r\n\r\n'.join([item.to_bytes() for item in responses]))
+
                 except socket.error:
                     print("[WARNING] Something was wrong with the socket connection, further investigation is needed if this issue persists")
                     break
-                except SNSserverException:
+                except SNSserverException as e:
+                    print(e)
                     print("[WARNING] A server exception occured, meaning something went wrong with loading in or sending a request")
                     break
         conn.close()
\ No newline at end of file
